@@ -22,6 +22,13 @@ impl TreeSitterParser {
             }
         }
 
+        let mut build = cc::Build::new();
+        build.include(&dir).warnings(false); // ignore unused parameter warnings
+        for file in c_files {
+            build.file(dir.join(file));
+        }
+        build.compile(self.name);
+
         if !cpp_files.is_empty() {
             let mut cpp_build = cc::Build::new();
             cpp_build
@@ -42,13 +49,6 @@ impl TreeSitterParser {
             }
             cpp_build.compile(&format!("{}-cpp", self.name));
         }
-
-        let mut build = cc::Build::new();
-        build.include(&dir).warnings(false); // ignore unused parameter warnings
-        for file in c_files {
-            build.file(dir.join(file));
-        }
-        build.compile(self.name);
     }
 }
 
@@ -104,6 +104,16 @@ fn main() {
             src_dir: "vendor/tree-sitter-elixir-src",
             extra_files: vec!["scanner.cc"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-gleam",
+            src_dir: "vendor/tree-sitter-gleam-src",
+            extra_files: vec![],
+        },
+        TreeSitterParser {
+            name: "tree-sitter-elm",
+            src_dir: "vendor/tree-sitter-elm-src",
+            extra_files: vec!["scanner.cc"],
+        },
         TreeSitterParser {
             name: "tree-sitter-go",
             src_dir: "vendor/tree-sitter-go-src",
@@ -189,6 +199,16 @@ fn main() {
             src_dir: "vendor/tree-sitter-typescript-src/typescript/src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-yaml",
+            src_dir: "vendor/tree-sitter-yaml-src",
+            extra_files: vec!["scanner.cc"],
+        },
+        TreeSitterParser {
+            name: "tree-sitter-zig",
+            src_dir: "vendor/tree-sitter-zig-src",
+            extra_files: vec![],
+        },
     ];
 
     // Only rerun if relevant files in the vendor/ directory change.
