@@ -13,6 +13,7 @@
 // the number of arguments and triggering this lint.
 #![allow(clippy::too_many_arguments)]
 
+mod constants;
 mod context;
 mod dijkstra;
 mod files;
@@ -50,7 +51,7 @@ use mimalloc::MiMalloc;
 #[global_allocator]
 static GLOBAL: MiMalloc = MiMalloc;
 
-use options::{should_use_color, Mode};
+use options::{should_use_color, DisplayMode, Mode};
 use sliders::fix_all_sliders;
 use std::{env, path::Path};
 use style::BackgroundColor;
@@ -88,11 +89,16 @@ fn main() {
     reset_sigpipe();
 
     match options::parse_args() {
-        Mode::DumpTreeSitter { path } => {
+        Mode::DumpTreeSitter {
+            path,
+            language_override,
+        } => {
             let path = Path::new(&path);
             let bytes = read_or_die(path);
             let src = String::from_utf8_lossy(&bytes).to_string();
-            match guess(path, &src) {
+
+            let language = language_override.or_else(|| guess(path, &src));
+            match language {
                 Some(lang) => {
                     let ts_lang = tsp::from_language(lang);
                     let tree = tsp::parse_to_tree(&src, &ts_lang);
@@ -103,12 +109,16 @@ fn main() {
                 }
             }
         }
-        Mode::DumpSyntax { path } => {
+        Mode::DumpSyntax {
+            path,
+            language_override,
+        } => {
             let path = Path::new(&path);
             let bytes = read_or_die(path);
             let src = String::from_utf8_lossy(&bytes).to_string();
 
-            match guess(path, &src) {
+            let language = language_override.or_else(|| guess(path, &src));
+            match language {
                 Some(lang) => {
                     let ts_lang = tsp::from_language(lang);
                     let arena = Arena::new();
@@ -126,10 +136,12 @@ fn main() {
             byte_limit,
             print_unchanged,
             missing_as_empty,
+            display_mode,
             background_color,
             color_output,
             display_width,
             display_path,
+            language_override,
             lhs_path,
             rhs_path,
             ..
@@ -151,12 +163,18 @@ fn main() {
             }
 
             if lhs_path.is_dir() && rhs_path.is_dir() {
-                for diff_result in
-                    diff_directories(lhs_path, rhs_path, missing_as_empty, node_limit, byte_limit)
-                {
+                for diff_result in diff_directories(
+                    lhs_path,
+                    rhs_path,
+                    missing_as_empty,
+                    node_limit,
+                    byte_limit,
+                    language_override,
+                ) {
                     print_diff_result(
                         display_width,
                         use_color,
+                        display_mode,
                         background_color,
                         print_unchanged,
                         &diff_result,
@@ -170,10 +188,12 @@ fn main() {
                     missing_as_empty,
                     node_limit,
                     byte_limit,
+                    language_override,
                 );
                 print_diff_result(
                     display_width,
                     use_color,
+                    display_mode,
                     background_color,
                     print_unchanged,
                     &diff_result,
@@ -191,9 +211,17 @@ fn diff_file(
     missing_as_empty: bool,
     node_limit: u32,
     byte_limit: usize,
+    language_override: Option<guess_language::Language>,
 ) -> DiffResult {
     let (lhs_bytes, rhs_bytes) = read_files_or_die(lhs_path, rhs_path, missing_as_empty);
-    diff_file_content(display_path, &lhs_bytes, &rhs_bytes, node_limit, byte_limit)
+    diff_file_content(
+        display_path,
+        &lhs_bytes,
+        &rhs_bytes,
+        node_limit,
+        byte_limit,
+        language_override,
+    )
 }
 
 fn diff_file_content(
@@ -202,6 +230,7 @@ fn diff_file_content(
     rhs_bytes: &[u8],
     node_limit: u32,
     byte_limit: usize,
+    language_override: Option<guess_language::Language>,
 ) -> DiffResult {
     if is_probably_binary(lhs_bytes) || is_probably_binary(rhs_bytes) {
         return DiffResult {
@@ -243,14 +272,15 @@ fn diff_file_content(
     } else {
         &rhs_src
     };
-    let ts_lang = guess(path, guess_src).map(tsp::from_language);
+    let language = language_override.or_else(|| guess(path, guess_src));
+    let lang_config = language.map(tsp::from_language);
 
     if lhs_bytes == rhs_bytes {
         // If the two files are completely identical, return early
         // rather than doing any more work.
         return DiffResult {
             path: display_path.into(),
-            language: ts_lang.map(|l| l.name.into()),
+            language: lang_config.map(|l| l.name.into()),
             lhs_src: FileContent::Text("".into()),
             rhs_src: FileContent::Text("".into()),
             lhs_positions: vec![],
@@ -258,7 +288,7 @@ fn diff_file_content(
         };
     }
 
-    let (lang_name, lhs_positions, rhs_positions) = match ts_lang {
+    let (lang_name, lhs_positions, rhs_positions) = match lang_config {
         _ if lhs_bytes.len() > byte_limit || rhs_bytes.len() > byte_limit => {
             let lhs_positions = line_parser::change_positions(&lhs_src, &rhs_src);
             let rhs_positions = line_parser::change_positions(&rhs_src, &lhs_src);
@@ -305,8 +335,9 @@ fn diff_file_content(
                         rhs_section_nodes.get(0).copied(),
                     );
 
-                    fix_all_sliders(&lhs_section_nodes);
-                    fix_all_sliders(&rhs_section_nodes);
+                    let language = language.unwrap();
+                    fix_all_sliders(language, &lhs_section_nodes);
+                    fix_all_sliders(language, &rhs_section_nodes);
                 }
 
                 let lhs_positions = syntax::change_positions(&lhs);
@@ -343,6 +374,7 @@ fn diff_directories<'a>(
     missing_as_empty: bool,
     node_limit: u32,
     byte_limit: usize,
+    language_override: Option<guess_language::Language>,
 ) -> impl Iterator<Item = DiffResult> + 'a {
     WalkDir::new(lhs_dir)
         .into_iter()
@@ -362,6 +394,7 @@ fn diff_directories<'a>(
                 missing_as_empty,
                 node_limit,
                 byte_limit,
+                language_override,
             )
         })
 }
@@ -370,6 +403,7 @@ fn diff_directories<'a>(
 fn print_diff_result(
     display_width: usize,
     use_color: bool,
+    display_mode: DisplayMode,
     background: BackgroundColor,
     print_unchanged: bool,
     summary: &DiffResult,
@@ -406,31 +440,35 @@ fn print_diff_result(
                 return;
             }
 
-            if env::var("INLINE").is_ok() {
-                inline::print(
-                    lhs_src,
-                    rhs_src,
-                    &summary.lhs_positions,
-                    &summary.rhs_positions,
-                    &hunks,
-                    &summary.path,
-                    &lang_name,
-                    use_color,
-                    background,
-                );
-            } else {
-                side_by_side::print(
-                    &hunks,
-                    display_width,
-                    use_color,
-                    background,
-                    &summary.path,
-                    &lang_name,
-                    lhs_src,
-                    rhs_src,
-                    &summary.lhs_positions,
-                    &summary.rhs_positions,
-                );
+            match display_mode {
+                DisplayMode::Inline => {
+                    inline::print(
+                        lhs_src,
+                        rhs_src,
+                        &summary.lhs_positions,
+                        &summary.rhs_positions,
+                        &hunks,
+                        &summary.path,
+                        &lang_name,
+                        use_color,
+                        background,
+                    );
+                }
+                DisplayMode::SideBySide | DisplayMode::SideBySideShowBoth => {
+                    side_by_side::print(
+                        &hunks,
+                        display_width,
+                        use_color,
+                        display_mode,
+                        background,
+                        &summary.path,
+                        &lang_name,
+                        lhs_src,
+                        rhs_src,
+                        &summary.lhs_positions,
+                        &summary.rhs_positions,
+                    );
+                }
             }
         }
         (FileContent::Binary(lhs_bytes), FileContent::Binary(rhs_bytes)) => {
@@ -495,6 +533,7 @@ mod tests {
             s.as_bytes(),
             DEFAULT_NODE_LIMIT,
             DEFAULT_BYTE_LIMIT,
+            None,
         );
 
         assert_eq!(res.lhs_positions, vec![]);
